==> spip_3.2.11.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Bem vindo @nom@!',
	'c_accueil_configurer_site' => 'Configurar o seu site',
	'c_accueil_configurer_site_texte' => 'Uma das primeiras coisas a fazer é dar um nome ao seu site.
Atualmente, ele se chama « @nom@ ». O nome do site é exibido no alto desta página.Clicando abaixo, você poderá alterar o seu nome, bem como definir um logo e um slogan.',
	'c_accueil_publication' => 'Publicar!',
	'c_accueil_publication_texte' => 'Para publicar uma página, você precisa criar uma matéria.
Para isso, é necessário que você crie pelo menos uma seção. Você pode fazê-lo no menu « Edição », clicando em « Seções ».',
	'c_accueil_texte' => 'Você acaba de entrar na área privada do SPIP.',
	'c_accueil_texte_revenir' => 'Esta página exibe a atividade editorial recente no seu site.
Você pode voltar a esta página a qualquer momento clicando no ícone da casa, no cabeçalho, sob o seu nome.',
	'c_article_redaction' => 'A matéria está em fase de redação',
	'c_article_redaction_redacteur' => 'A matéria está em fase de redação',
	'c_article_redaction_redacteur_texte' => 'Para propor a sua matéria aos administradores do site e aos outros redatores, no box ao lado, altere «em fase de redação» por «proposta para publicação».',
	'c_article_redaction_texte' => 'Para publicar esta matéria na área pública, é necessário alterar o seu status. No box ao lado mude de «em fase de redação» para «publicado online»',
	'c_articles_creer' => 'Como criar uma matéria?',
	'c_articles_creer_texte' => 'Você só poderá criar uma matéria a partir desta página após ter criado uma seção no seu site.
Você pode criá-la a partir do  menu « Edição » e, em seguida « Seções ».',
	'c_job' => 'As tarefas a executar…',
	'c_job_texte' => 'Esta página lista as próximas tarefas de manutenção que o SPIP deve efetuar. Estas tarefas são executadas em intervalos regulares, ou pontualmente para os procedimentos pesados solicitados pelos plugins, tais como o envio em massa de e-mails.',
	'c_rubrique_publier' => 'Crie uma matéria',
	'c_rubrique_publier_texte' => 'Uma seção só é exibida na área pública a partir do momento em que ela contenha pelo menos um conteúdo publicado. Crie então uma matéria. Você pode fazê-lo a partir desta página, abaixo da descrição da sua seção.',
	'c_rubriques_creer' => 'Crie uma primeira seção!',
	'c_rubriques_creer_texte' => 'As seções são a estrutura básica do site; você pode criar matérias em cada uma delas. Comece criando uma primeira seção.',
	'c_sites_creer' => 'Como criar ou importar um site?',
	'c_sites_creer_texte' => 'Você só poderá criar ou importar um site a partir desta página a partir do momento em que exista uma seção no seu site. Você poderá criá-la a partir do menu  «Edição», na opção «Seções».',

	// E
	'explication_activer_compagnon' => 'O companheiro inclui comentários em certas páginas da área restrita para ajudar a se familiarizar com o SPIP. Você quer ativá-lo?',
	'explication_reinitialiser_compagnon' => 'As mensagens já vistas por um autor não são mais exibidas. Você quer reinicializar essas mensagens?',

	// L
	'label_activer_compagnon' => 'Ativar o companheiro?',
	'label_reinitialiser_compagnon' => 'Reinicializar as mensagens do companheiro?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Bom!',
	'ok_jai_compris' => 'Entendido!',
	'ok_merci' => 'Obrigado',
	'ok_parfait' => 'Perfeito!',

	// R
	'reinitialisation' => 'Reinicialização',
	'reinitialisation_ok' => 'A reinicialização foi efetuada.',
	'reinitialiser' => 'Reinicializar',
	'reinitialiser_moi' => 'Sim, apenas as que eu já li',
	'reinitialiser_tous' => 'Sim, para qualquer autor',

	// T
	'titre_compagnon' => 'O Companheiro',
	'titre_page_configurer_compagnon' => 'Configurar o Companheiro'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_tout_compris' => 'Ocultar todas as mensagens do Companheiro',
	'bouton_tout_compris_explication' => 'Se você já conhece o SPIP, você pode ignorar todas as mensagens do Companheiro; senão, cada mensagem pode ser fechada individualmente.',

	// C
	'c_accueil_bienvenue' => 'Bem vindo @nom@!',
	'c_accueil_configurer_site' => 'Configurar o seu site',
	'c_accueil_configurer_site_texte' => 'Uma das primeiras coisas a fazer é dar um nome ao seu site.
Atualmente, ele se chama « @nom@ ». O nome do site é exibido no alto desta página.Clicando abaixo, você poderá alterar o seu nome, bem como definir um logo e um slogan.',
	'c_accueil_publication' => 'Publicar!',
	'c_accueil_publication_texte' => 'Para publicar uma página, você precisa criar uma matéria.
Para isso, é necessário que você crie pelo menos uma seção. Você pode fazê-lo no menu « Edição », clicando em « Seções ».',
	'c_accueil_texte' => 'Você acaba de entrar na área privada do SPIP.',
	'c_accueil_texte_revenir' => 'Esta página exibe a atividade editorial recente no seu site.
Você pode voltar a esta página a qualquer momento clicando no ícone da casa, no cabeçalho, sob o seu nome.',
	'c_article_redaction' => 'A matéria está em fase de redação',
	'c_article_redaction_redacteur' => 'A matéria está em fase de redação',
	'c_article_redaction_redacteur_texte' => 'Para propor a sua matéria aos administradores do site e aos outros redatores, no box ao lado, altere «em fase de redação» por «proposta para publicação».',
	'c_article_redaction_texte' => 'Para publicar esta matéria na área pública, é necessário alterar o seu status. No box ao lado mude de «em fase de redação» para «publicado online»',
	'c_articles_creer' => 'Como criar uma matéria?',
	'c_articles_creer_texte' => 'Você só poderá criar uma matéria a partir desta página após ter criado uma seção no seu site.
Você pode criá-la a partir do  menu « Edição » e, em seguida « Seções ».',
	'c_job' => 'As tarefas a executar…',
	'c_job_texte' => 'Esta página lista as próximas tarefas de manutenção que o SPIP deve efetuar. Estas tarefas são executadas em intervalos regulares, ou pontualmente para os procedimentos pesados solicitados pelos plugins, tais como o envio em massa de e-mails.',
	'c_rubrique_publier' => 'Crie uma matéria',
	'c_rubrique_publier_texte' => 'Uma seção só é exibida na área pública a partir do momento em que ela contenha pelo menos um conteúdo publicado. Crie então uma matéria. Você pode fazê-lo a partir desta página, abaixo da descrição da sua seção.',
	'c_rubriques_creer' => 'Crie uma primeira seção!',
	'c_rubriques_creer_texte' => 'As seções são a estrutura básica do site; você pode criar matérias em cada uma delas. Comece criando uma primeira seção.',
	'c_sites_creer' => 'Como criar ou importar um site?',
	'c_sites_creer_texte' => 'Você só poderá criar ou importar um site a partir desta página a partir do momento em que exista uma seção no seu site. Você poderá criá-la a partir do menu  «Edição», na opção «Seções».',

	// E
	'explication_activer_compagnon' => 'O companheiro inclui comentários em certas páginas da área restrita para ajudar a se familiarizar com o SPIP. Você quer ativá-lo?',
	'explication_reinitialiser_compagnon' => 'As mensagens já vistas por um autor não são mais exibidas. Você quer reinicializar essas mensagens?',

	// L
	'label_activer_compagnon' => 'Ativar o companheiro?',
	'label_reinitialiser_compagnon' => 'Reinicializar as mensagens do companheiro?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Bom!',
	'ok_jai_compris' => 'Entendido!',
	'ok_merci' => 'Obrigado',
	'ok_parfait' => 'Perfeito!',

	// R
	'reinitialisation' => 'Reinicialização',
	'reinitialisation_ok' => 'A reinicialização foi efetuada.',
	'reinitialiser' => 'Reinicializar',
	'reinitialiser_moi' => 'Sim, apenas as que eu já li',
	'reinitialiser_tous' => 'Sim, para qualquer autor',

	// T
	'titre_compagnon' => 'O Companheiro',
	'titre_page_configurer_compagnon' => 'Configurar o Companheiro'
);
